DebugInfoCallback typedef
DebugInfoCallback =
Future<String?> Function(BuildContext context)
Signature for a callback that returns debug information as a string.
Used by DeveloperToolEntry.debugInfo and
DeveloperToolsExtension.debugInfo to contribute sections to the
aggregated debug report produced by exportDeveloperToolsReport().
Return null to indicate that there is nothing to report.
Implementation
typedef DebugInfoCallback = Future<String?> Function(BuildContext context);